#
# spec file for package python-pycrdt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pycrdt
Version:        0.10.6
Release:        1.4
Summary:        Python bindings for Yrs
License:        MIT
URL:            https://github.com/jupyter-server/pycrdt
Source0:        pycrdt-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module maturin >= 1.4.0}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-anyio >= 4.4 with python-anyio < 5)
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 7.4.2}
BuildRequires:  %{python_module anyio >= 4.4.0 with %python-anyio < 5}
BuildRequires:  %{python_module exceptiongroup if %python-base < 3.11}
BuildRequires:  %{python_module trio >= 0.25.1 with %python-trio < 0.27}
# /SECTION
%python_subpackages

%description
Pycrdt is a Python CRDT library that provides bindings for Yrs, the Rust port of the Yjs framework.

Conflict-free Replicated Data Types (CRDTs) allow creating shared documents that can automatically
merge changes made concurrently on different "copies" of the data. When the data lives on different
machines, they make it possible to build distributed systems that work with local data, leaving the
synchronization and conflict resolution with remote data to the CRDT algorithm, which ensures that
all data replicas eventually converge to the same state.

%prep
%autosetup -p1 -n pycrdt-%{version} -a1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# pydantic is too old
%pytest_arch --ignore tests/test_model.py

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/pycrdt
%{python_sitearch}/pycrdt-%{version}.dist-info

%changelog
* Mon Nov  4 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.10.6
  * Bump yrs v0.21.3 and pyo3 v0.22.5
- Releases from 0.9.15 to 0.10.5
  * Bump upper limit of trio by @bnavigator in #160
  * Add documentation about undo manager by @davidbrochart in #164
  * Add API reference by @davidbrochart in #165
  * Update GitHub actions by @davidbrochart in #167
  * Fix GitHub actions upload/download artifacts by @davidbrochart
    in #168
  * Fix GitHub action upload artifact by @davidbrochart in #169
  * Add awareness by @davidbrochart in #171
  * Add awareness features to handle server state by @brichet in
    [#170]
  * Fix set_local_state() and set_local_state_field() by
    @davidbrochart in #176
  * Bump Yrs v0.21.2 by @davidbrochart in #177
  * Add awareness by @davidbrochart in #171
  * Add CHANGELOG.md and automate release on tag.
  * Add support for XML, Text attributes and embeds (#184) (PR by
    @ColonelThirtyTwo).
* Mon Sep  9 2024 Ben Greiner <code@bnavigator.de>
- Bump upper limit of trio gh#jupyter-server/pycrdt#160
* Fri Sep  6 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.11
  * Add Doc.new_transaction() sync and async context managers by
    @davidbrochart in #154
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.8
  * Add update API by @Wh1isper in #148
- Changes from 0.8.17 to 0.9.8
  * Check origin in nested transactions by @davidbrochart in #146
  * Move global origin registry to document by @davidbrochart in
    [#145]
  * Fix origin by @davidbrochart in #144
  * Support transaction origin by @davidbrochart in #142
  * Bump pyo3 v0.22.2 by @davidbrochart in #143
  * Bump yrs v0.19.2 by @davidbrochart in #140
  * Allow multithreading by @davidbrochart in #137
  * Support undo manager expand_scope by @davidbrochart in #128
  * Export more from sync by @davidbrochart in #127
  * Add sync protocol (v1) by @davidbrochart in #124
  * Add undo manager by @davidbrochart in #119
  * Raise ValueError on Doc.get_update() error by @davidbrochart in
    [#118]
  * Ignore empty updates by @davidbrochart in #107, #111
  * really drop python<=support by @kloczek in #96
  * Shared Types Popped from Shared Map are Empty by @jbdyn in #94
* Fri Jun 28 2024 Steve Kowalik <steven.kowalik@suse.com>
- Remove upper bound on pytest.
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.8.17
  * Update yrs 0.18.2 by @davidbrochart in #92
- Releases 0.8.7 to 0.8.16
  * Export Subscription by @davidbrochart in #90
  * Fix possibly undefined _subscriptions by @davidbrochart in #88
  * Remove warning about project not ready for production by
    @davidbrochart in #82
  * Keep subscription references by @davidbrochart in #85
  * Fix doc observe by @davidbrochart in #87
  * Improve Doc.get return value type by @davidbrochart in #80
  * Add Doc.get() by @davidbrochart in #77
  * Add leading underscore to Python files by @davidbrochart in #75
  * Add update property to TransactionEvent by @davidbrochart in
    [#72]
* Mon Jan 22 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.8.6
  * Resolve "Text data type does not delete as expected" by @jbdyn
    in #68
- Releases in Between:
  * Bump yrs, pyo3, maturin
- Release 0.8.3
  * Support nested ReadTransaction by @davidbrochart in #59
  * Fix Map.pop default value handling by @davidbrochart in #60
  * Add contains method by @davidbrochart in #61
  * Support bytes by @davidbrochart in #62
  * Revert PR #58 by @davidbrochart in #63
* Thu Dec 28 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.8.2
- Required by jupyter-collaboration 2 (still incubating phase)
